@@ -42,6 +42,7 @@ from .types import (
     Scope,
     Send,
     WsHandlerType,
+    WsMiddlewareType,
 )
 
 allowed_methods_default = ["get", "post", "delete", "put", "patch", "options"]
@@ -105,7 +106,10 @@ class NexiosApp(object):
         try:
             from nexios.cli.utils import get_config as get_nexios_config
         except ImportError:
-            get_nexios_config = lambda: {}
+
+            def get_nexios_config():
+                return {}
+
         from nexios.config import get_config, set_config
 
         try:
@@ -130,6 +134,7 @@ class NexiosApp(object):
         self.router = self.app
         self.route = self.router.route
         self.lifespan_context: Optional[lifespan_manager] = lifespan
+        self.state = {}
 
         openapi_config: Dict[str, Any] = self.config.to_dict().get("openapi", {})  # type:ignore
         self.openapi_config = OpenAPIConfig(
@@ -271,7 +276,8 @@ class NexiosApp(object):
                         if self.lifespan_context:
                             # If a lifespan context manager is provided, use it
                             self.lifespan_manager: Any = self.lifespan_context(self)
-                            await self.lifespan_manager.__aenter__()
+                            returned_state = await self.lifespan_manager.__aenter__()
+                            self.state.update(returned_state)
                         else:
                             # Otherwise, fall back to the default startup handlers
                             await self._startup()
@@ -359,7 +365,7 @@ class NexiosApp(object):
             ```python
             def logging_middleware(request: Request, response: Response, next_call: Callable) -> Response:
                 print(f"Request received: {request.method} {request.url}")
-                return next_call(request, response)
+                return next_call()
 
             app.add_middleware(logging_middleware)
             ```
@@ -372,10 +378,15 @@ class NexiosApp(object):
 
     def add_ws_route(
         self,
-        route: Annotated[
-            WebsocketRoutes,
-            Doc("An instance of the Routes class representing a WebSocket route."),
-        ],
+        route: Optional[
+            Annotated[
+                WebsocketRoutes,
+                Doc("An instance of the Routes class representing a WebSocket route."),
+            ]
+        ] = None,
+        path: Optional[str] = None,
+        handler: Optional[WsHandlerType] = None,
+        middleware: List[WsMiddlewareType] = [],
     ) -> None:
         """
         Adds a WebSocket route to the application.
@@ -394,7 +405,12 @@ class NexiosApp(object):
             app.add_ws_route(route)
             ```
         """
-        self.ws_router.add_ws_route(route)
+        if route:
+            self.ws_router.add_ws_route(route)
+        else:
+            self.ws_router.add_ws_route(
+                WebsocketRoutes(path, handler, middleware=middleware)
+            )
 
     def mount_router(self, router: Router, path: Optional[str] = None) -> None:
         """
@@ -520,6 +536,8 @@ class NexiosApp(object):
         """ASGI application callable"""
         scope["app"] = self
         scope["base_app"] = self
+        scope["global_state"] = self.state
+
         if scope["type"] == "lifespan":
             await self.handle_lifespan(receive, send)
         elif scope["type"] == "http":
