@@ -1,6 +1,7 @@
-from .middleware import AuthenticationMiddleware
 from .backends.apikey import APIKeyAuthBackend
 from .backends.jwt import JWTAuthBackend, create_jwt, decode_jwt
+from .decorator import auth
+from .middleware import AuthenticationMiddleware
 
 __all__ = [
     "AuthenticationMiddleware",
@@ -8,4 +9,5 @@ __all__ = [
     "JWTAuthBackend",
     "create_jwt",
     "decode_jwt",
+    "auth",
 ]
