@@ -1,8 +1,9 @@
-from .base import WebSocket, WebSocketDisconnect   # type:ignore
-from .channels import Channel,ChannelBox
-from .consumers import WebSocketEndpoint
 import typing
 
+from .base import WebSocket, WebSocketDisconnect  # type:ignore
+from .channels import Channel, ChannelBox
+from .consumers import WebSocketConsumer
+
 Scope = typing.MutableMapping[str, typing.Any]
 Message = typing.MutableMapping[str, typing.Any]
 
@@ -11,5 +12,9 @@ Send = typing.Callable[[Message], typing.Awaitable[None]]
 
 
 __all__ = [
-    "WebSocket","Channel","ChannelBox","WebSocketEndpoint"
-]
\ No newline at end of file
+    "WebSocket",
+    "Channel",
+    "ChannelBox",
+    "WebSocketConsumer",
+    "WebSocketDisconnect",
+]
